pub struct Config {
pub services: BTreeMap<String, Vec<Service>>,
}Fields
services: BTreeMap<String, Vec<Service>>A map from the hash of FMD secret key to the services it is registered with
Implementations
Sourceimpl Config
impl Config
Sourcepub fn load_or_new(path: impl AsRef<Path>) -> Result<Self>
pub fn load_or_new(path: impl AsRef<Path>) -> Result<Self>
Load a config if it exists, otherwise create a new one
Sourcepub fn save(&mut self, path: impl AsRef<Path>) -> Result<()>
pub fn save(&mut self, path: impl AsRef<Path>) -> Result<()>
Save the config at the specified path
Sourcepub fn add_service(&mut self, key: String, url: &str, enc_key: EncKey)
pub fn add_service(&mut self, key: String, url: &str, enc_key: EncKey)
Add a new service which a specified key will be registered to.
Sourcepub fn get_services(&self, key: &String) -> Vec<Service>
pub fn get_services(&self, key: &String) -> Vec<Service>
Get the services that the specified key is configured to be registered to