pub struct Service {
pub url: String,
pub index: usize,
pub enc_key: EncKey,
}Expand description
A service instance
Fields
url: StringAddress of the service
index: usizeAn index indication which share of fmd keys it received
enc_key: EncKeyThe key used to decrypt responses from the service